@@ -1,4 +1,4 @@
-# Copyright 2022 Tiger Miao
+# Copyright 2022 Tiger Miao and collaborators.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -25,3 +25,5 @@ and use @snooping(...) to print the running result information of echo line code
 
 from .proposer import ProposalAction as proposal
 from .tracker import Tracker as tracking
+from .migrator.diff_handler import DifferenceFinder as diff_finder
+from .migrator.diff_handler import WeightMigrator as weight_migrator
