@@ -1,4 +1,4 @@
-# Copyright 2022 Tiger Miao
+# Copyright 2022 Tiger Miao and collaborators.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,8 +15,9 @@
 
 compiler_experience_list_cn = [
     {
-        "Fault Type": "construct 参数错误",
-        "Key Log Information": "For 'Cell', the function construct need 0 positional argument and 0 default argument",
+        "ID": "compiler_id_1",
+        "Fault Name": "construct 参数错误 <2.0",
+        "Key Log Information": "For 'Cell', the function construct .* 0 positional argument and 0 default argument",
         "Key Python Stack Information": "",
         "Key C++ Stack Information": "",
         "Fault Cause": "继承nn.Cell类，重定义construct函数时，缺少self参数报错",
@@ -30,35 +31,59 @@ compiler_experience_list_cn = [
         "Fault Case": """1.nn.Cell 官方文档:
                    https://www.mindspore.cn/docs/api/zh-CN/r1.6/api_python/nn/mindspore.nn.Cell.html
                    2.缺少self参数报错案例:
-                   https://bbs.huaweicloud.com/forum/thread-178902-1-1.html"""},
+                   https://bbs.huaweicloud.com/forum/thread-178902-1-1.html""",
+        "Test Case": "test_compiler_no_self.py"},
+    # Different versions have different error descriptions, and the ID is used repeatedly
     {
-     "Fault Type":"construct 参数错误",
-     "Key Log Information":"For 'Cell', the function construct need .* positional argument, but got .*",
-     "Key Python Stack Information":"",
-     "Key C++ Stack Information":"",
-     "Fault Cause":"继承nn.Cell类，重定义construct函数时，定义参数个数与调用时输入参数不匹配报错",
-     "Error Case":"""
-                     class Net_LessInput(Cell):
-                       def construct(self,x,y):
-                          return x + y
-                     net = Net_LessInput()
-                     out = net(1)
-                               ^~~~~~~ 此处缺少1个输入参数""",
-     "Modification Suggestion":"检查construct函数定义参数与调用输入参数，如果参数不匹配，"
-                               "请根据情况修改参数定义或输入参数。",
-     "Fixed Case":"""
-                    class Net_LessInput(Cell):
-                     def construct(self,x,y):
-                         return x + y
-                    net = Net_LessInput()
-                    out = net(1,2)
-                               ^~~~~~~ 此处增加1个输入参数""",
-     "Fault Case":"""1.nn.Cell官方文档：
-                  https://www.mindspore.cn/docs/api/zh-CN/r1.6/api_python/nn/mindspore.nn.Cell.html
-                  2.参考缺少self参数报错案例：
-                  https://bbs.huaweicloud.com/forum/thread-178902-1-1.html"""},
-    {   
-        "Fault Type":"construct 参数错误",
+        "ID": "compiler_id_1",
+        "Fault Name": "construct 参数错误 >2.0",
+        "Key Log Information": "For 'Cell', the method 'construct' must have parameter 'self'",
+        "Key Python Stack Information": "",
+        "Key C++ Stack Information": "",
+        "Fault Cause": "继承nn.Cell类，重定义construct函数时，缺少self参数报错",
+        "Error Case": """
+                  def construct(a,b):
+                                ^~~~~~~ 此处缺少了self""",
+        "Modification Suggestion": "修改construct定义,添加self参数.",
+        "Fixed Case": """
+                  def construct(self,a,b):
+                                  ^~~~~~~ 添加self""",
+        "Fault Case": """1.nn.Cell 官方文档:
+               https://www.mindspore.cn/docs/api/zh-CN/r1.6/api_python/nn/mindspore.nn.Cell.html
+               2.缺少self参数报错案例:
+               https://bbs.huaweicloud.com/forum/thread-178902-1-1.html""",
+        "Test Case": "test_compiler_no_self.py"},
+
+    {
+         "ID": "compiler_id_2",
+         "Fault Name":"construct 参数错误",
+         "Key Log Information":"For 'Cell', the function construct .* positional argument, but got .*",
+         "Key Python Stack Information":"",
+         "Key C++ Stack Information":"",
+         "Fault Cause":"继承nn.Cell类，重定义construct函数时，定义参数个数与调用时输入参数不匹配报错",
+         "Error Case":"""
+                         class Net_LessInput(Cell):
+                           def construct(self,x,y):
+                              return x + y
+                         net = Net_LessInput()
+                         out = net(1)
+                                   ^~~~~~~ 此处缺少1个输入参数""",
+         "Modification Suggestion":"检查construct函数定义参数与调用输入参数，如果参数不匹配，"
+                                   "请根据情况修改参数定义或输入参数。",
+         "Fixed Case":"""
+                        class Net_LessInput(Cell):
+                         def construct(self,x,y):
+                             return x + y
+                        net = Net_LessInput()
+                        out = net(1,2)
+                                   ^~~~~~~ 此处增加1个输入参数""",
+         "Fault Case":"""1.nn.Cell官方文档：
+                      https://www.mindspore.cn/docs/api/zh-CN/r1.6/api_python/nn/mindspore.nn.Cell.html
+                      2.参考缺少self参数报错案例：
+                      https://bbs.huaweicloud.com/forum/thread-178902-1-1.html"""},
+    {
+        "ID": "compiler_id_3",
+        "Fault Name":"construct 参数错误",
         "Key Log Information":"construct\(\) missing [1-9] required positional argument.*",
         "Key Python Stack Information":"",
         "Key C++ Stack Information":"",
@@ -84,33 +109,35 @@ compiler_experience_list_cn = [
                   2.参考缺少self参数报错案例：
                   https://bbs.huaweicloud.com/forum/thread-178902-1-1.html"""},
     {
-     "Fault Type":"construct 参数错误",
-     "Key Log Information":"For 'Cell', the function construct need [1-9] positional argument and "
-                         "[0-9] default argument, total .*",
-     "Key Python Stack Information":"",
-     "Key C++ Stack Information":"",
-     "Fault Cause":"继承nn.Cell类，重定义construct函数时，定义参数个数与调用时输入参数不匹配报错",
-     "Error Case":"""
-                class Net_MoreInput(Cell):
-                   def construct(self,x):
-                       return x
-                 net = Net_MoreInput()
-                 out = net(1, 2)
-                              ^~~~~~~ 此处多1个输入参数""",
-     "Modification Suggestion":"检查construct函数定义参数与调用输入参数，如果参数不匹配，请根据情况修改参数定义或输入参数。",
-     "Fixed Case":"""
-                 class Net_MoreInput(Cell):
-                   def construct(self,x):
-                       return x
-                 net = Net_MoreInput()
-                 out = net(1)
-                           ^~~~~~~ 此处去掉1个输入参数""",
-     "Fault Case":"""1.nn.Cell官方文档:
-              https://www.mindspore.cn/docs/api/zh-CN/r1.6/api_python/nn/mindspore.nn.Cell.html
-              2.参考缺少self参数报错案例:
-              https://bbs.huaweicloud.com/forum/thread-178902-1-1.html"""},
+         "ID": "compiler_id_4",
+         "Fault Name":"construct 参数错误",
+         "Key Log Information":"For 'Cell', the function construct .* [1-9] positional argument and "
+                             "[0-9] default argument, total .*",
+         "Key Python Stack Information":"",
+         "Key C++ Stack Information":"",
+         "Fault Cause":"继承nn.Cell类，重定义construct函数时，定义参数个数与调用时输入参数不匹配报错",
+         "Error Case":"""
+                    class Net_MoreInput(Cell):
+                       def construct(self,x):
+                           return x
+                     net = Net_MoreInput()
+                     out = net(1, 2)
+                                  ^~~~~~~ 此处多1个输入参数""",
+         "Modification Suggestion":"检查construct函数定义参数与调用输入参数，如果参数不匹配，请根据情况修改参数定义或输入参数。",
+         "Fixed Case":"""
+                     class Net_MoreInput(Cell):
+                       def construct(self,x):
+                           return x
+                     net = Net_MoreInput()
+                     out = net(1)
+                               ^~~~~~~ 此处去掉1个输入参数""",
+         "Fault Case":"""1.nn.Cell官方文档:
+                  https://www.mindspore.cn/docs/api/zh-CN/r1.6/api_python/nn/mindspore.nn.Cell.html
+                  2.参考缺少self参数报错案例:
+                  https://bbs.huaweicloud.com/forum/thread-178902-1-1.html"""},
     {
-        "Fault Type":"construct 参数错误",
+        "ID": "compiler_id_5",
+        "Fault Name":"construct 参数错误",
         "Key Log Information":"construct\(\) takes [1-9] positional arguments but [0-9] were given",
         "Key Python Stack Information":"",
         "Key C++ Stack Information":"",
@@ -135,7 +162,8 @@ compiler_experience_list_cn = [
               2.参考缺少self参数报错案例:
               https://bbs.huaweicloud.com/forum/thread-178902-1-1.html"""},
     {
-     "Fault Type": "自定义接口参数错误",
+     "ID": "compiler_id_6",
+     "Fault Name": "自定义接口参数错误",
      "Key Log Information": ".* parameters number of the function is .*but .*",
      "Key Python Stack Information": "",
      "Key C++ Stack Information": "",
@@ -166,7 +194,8 @@ compiler_experience_list_cn = [
      "Fault Case": """1.使用analyze_fail.dat分析函数参数错误案例:
                      https://www.mindspore.cn/docs/programming_guide/zh-CN/r1.6/read_ir_files.html#analyze-fail-dat"""},
     {
-        "Fault Type": "自定义接口参数错误",
+        "ID": "compiler_id_7",
+        "Fault Name": "自定义接口参数错误",
         "Key Log Information": ".* takes . positional arguments but . were given",
         "Key Python Stack Information": "",
         "Key C++ Stack Information": "",
@@ -197,7 +226,8 @@ compiler_experience_list_cn = [
         "Fault Case":"1.使用analyze_fail.dat分析函数参数错误案例: "
                      "https://www.mindspore.cn/docs/programming_guide/zh-CN/r1.6/read_ir_files.html#analyze-fail-dat"},
     {
-     "Fault Type": "抽象类型合并失败",
+     "ID": "compiler_id_8",
+     "Fault Name": "抽象类型合并失败",
      "Key Log Information": "Type Join Failed: dtype1 = .*, dtype2 = .*",
      "Key Python Stack Information": "",
      "Key C++ Stack Information": "",
@@ -211,27 +241,31 @@ compiler_experience_list_cn = [
                          return self.cast(self.relu(x), ms.float16)
                              ^~~~~~~ 返回值类型与if分支不一致""",
      "Modification Suggestion": "检查不同分支的返回结果的类型，如果类型不相同，请修改至相同类型。",
-     "Fault Case": """编译时报错Type Join Failed案例:
+     "Fault Case": """1.编译时报错Type Join Failed案例:
                    https://www.mindspore.cn/docs/faq/zh-CN/r1.6/network_compilation.html"""},
     {
-     "Fault Type": "抽象类型合并失败",
+     "ID": "compiler_id_9",
+     "Fault Name": "抽象类型合并失败",
      "Key Log Information": "Shape Join Failed: shape1 = .*, shape2 = .*",
      "Key Python Stack Information": "",
      "Key C++ Stack Information": "",
      "Fault Cause": "静态图的控制流(例如:if...else...)语法要求不同分支返回值的shape相同，不相同时会报错。",
      "Error Case": """
                      def construct(self, x, a, b):
-                        if a > b:
-                          return self.relu(x)
-                        else:
-                          # shape: (*)->()
-                          return self.reducesum(x)
-                            ^~~~~~~返回值shape与if分支不一致 """,
+                         if a > b:
+                             return self.relu(x)
+                         else:
+                             # shape: (*)->()
+                             return self.reducesum(x)
+                                 ^~~~~~~返回值shape与if分支不一致 """,
      "Modification Suggestion": "检查不同分支的返回结果的shape，如果不相同，请修改至相同shape",
-     "Fault Case": """编译时报错Shape Join Failed案例:
-                   https://www.mindspore.cn/docs/faq/zh-CN/r1.6/network_compilation.html"""},
+     "Fault Case": """1.编译时报错Shape Join Failed案例:
+                   https://www.mindspore.cn/docs/faq/zh-CN/r1.6/network_compilation.html
+                   2.静态图语法：
+                   https://www.mindspore.cn/docs/note/zh-CN/r1.6/static_graph_syntax_support.html"""},
     {
-     "Fault Type": "抽象类型合并失败",
+     "ID": "compiler_id_10",
+     "Fault Name": "抽象类型合并失败",
      "Key Log Information": "Abstract type .* cannot join with .*",
      "Key Python Stack Information": "",
      "Key C++ Stack Information": "",
@@ -271,10 +305,11 @@ compiler_experience_list_cn = [
                   x = Tensor([1.0])
                   y = Tensor([2.0])
                   join_fail(x,y)""",
-     "Fault Case": """自动求导报错Type Join Failed案例:
+     "Fault Case": """1.自动求导报错Type Join Failed案例:
                https://www.mindspore.cn/docs/faq/zh-CN/r1.6/network_compilation.html""" },
     {
-     "Fault Type": "静态图编译错误",
+     "ID": "compiler_id_11",
+     "Fault Name": "静态图找不到属性-1.8.1",
      "Key Log Information": "operation does not support the type",
      "Key Python Stack Information": "",
      "Key C++ Stack Information": "GenerateFromTypes",
@@ -296,18 +331,48 @@ compiler_experience_list_cn = [
      "Fault Case": "1.静态图语法： "
                    "https://www.mindspore.cn/docs/note/zh-CN/r1.6/static_graph_syntax_support.html "
                    "2.使用未定义变量报错案例： "
-                   "https://bbs.huaweicloud.com/forum/thread-180857-1-1.html"},
+                   "https://bbs.huaweicloud.com/forum/thread-180857-1-1.html",
+     "Test Case": "test_compiler_kmetatypenone.py"},
     {
-     "Fault Type": "函数调用栈超限",
+        "ID": "compiler_id_12",
+        "Fault Name": "静态图找不到属性-1.9",
+        "Key Log Information": "External object has no attribute",
+        "Key Python Stack Information": "",
+        "Key C++ Stack Information": "GetEvaluatedValueForNameSpaceString",
+        "Fault Cause": "静态图语法使用未定义的变量报错",
+        "Error Case": """
+                  class Net(nn.Cell):
+                    def construct(self, x):
+                      return x + self.y
+                                    ^~~~~~~ self.y未定义""",
+        "Modification Suggestion": "定位到报错代码行，如果变量未定义，可以在__init__方法中初始化。",
+        "Fixed Case": """
+                  class Net(nn.Cell):
+                    def __init__(self):
+                      super(Net, self).__init__()
+                      self.y = 1.0
+                         ^~~~~~~ 对self.y初始化
+                    def construct(self, x):
+                      return x + self.y""",
+        "Fault Case": "1.静态图语法： "
+                      "https://www.mindspore.cn/docs/note/zh-CN/r1.6/static_graph_syntax_support.html "
+                      "2.使用未定义变量报错案例： "
+                      "https://bbs.huaweicloud.com/forum/thread-180857-1-1.html",
+        "Test Case": "test_compiler_kmetatypenone.py"},
+    {
+     "ID": "compiler_id_13",
+     "Fault Name": "函数调用栈超限",
      "Key Log Information": "Exceed function call depth limit",
      "Key Python Stack Information": "",
      "Key C++ Stack Information": "",
      "Fault Cause": "函数嵌套调用存在死循环或者嵌套调用深度超过限制而引起报错",
      "Modification Suggestion": "1.检查代码中是否存在无穷递归或死循环，简化代码逻辑减少函数循环嵌套调用 "
                                 "2.使用context.set_context(max_call_depth=value)方法，修改函数调用栈最大深度限制。",
-     "Fault Case": "GRU算子参数过大引起栈超限制案例: "
+     "Fault Case": "1.GRU算子参数过大引起栈超限制案例: "
                    "https://bbs.huaweicloud.com/forum/thread-182256-1-1.html"},
-    {"Fault Type": "JIT Fallback 使用错误",
+    {
+     "ID": "compiler_id_14",
+     "Fault Name": "JIT Fallback 使用错误",
      "Key Log Information": "not use Python object in runtime",
      "Key Python Stack Information": "",
      "Key C++ Stack Information": "",
@@ -328,11 +393,12 @@ compiler_experience_list_cn = [
                         z = Tensor(np.add(x, y))
                                       ^~~~不支持的语法，在编译期执行。
                         return z""",
-     "Fault Case": "JIT Fallback使用说明： "
+     "Fault Case": "1.JIT Fallback使用说明： "
                    "https://www.mindspore.cn/docs/programming_guide/zh-CN/r1.6/jit_fallback.html"},
     {
-     "Fault Type": "使用自定义class的属性与方法",
-     "Key Log Information": "Not supported to get attribute for .*",
+     "ID": "compiler_id_15",
+     "Fault Name": "使用自定义class的属性与方法-1.8",
+     "Key Log Information": "Not supported to get attribute for InterpretedObject.*",
      "Key Python Stack Information": "",
      "Key C++ Stack Information": "",
      "Fault Cause": "静态图语法不支持自定义class的属性与方法， 在construct函数中使用出现报错",
@@ -355,10 +421,39 @@ compiler_experience_list_cn = [
                         weight = self._fc(x, output_size)
                         ...""",
      "Modification Suggestion": "当前版本不支持使用自定义类的属性与方法，请修改自定义类方法，或尝试使用最新版本。",
-     "Fault Case": "静态图语法支持： "
+     "Fault Case": "1.静态图语法支持： "
                    "https://www.mindspore.cn/docs/note/zh-CN/r1.6/static_graph_syntax_support.html"},
     {
-     "Fault Type": "静态图代码缩进错误",
+        "ID": "compiler_id_16",
+        "Fault Name": "使用自定义class的属性与方法-1.9",
+        "Key Log Information": "Do not support to get attribute from .* object .*",
+        "Key Python Stack Information": "",
+        "Key C++ Stack Information": "StaticGetter",
+        "Fault Cause": "静态图语法不支持调用自定义class的属性与方法， 在construct函数中使用出现报错",
+        "Error Case": """
+                class LayerParams:
+                    def get_weights(self, shape):
+                        ...
+                        nn_param=mindspore.Parameter(nn_param)
+                        return nn_param
+                class MyCell(nn.Cell):
+                    def __init__(self):
+                        super().__init__()
+                        self._params=LayerParams(...)
+                    def _fc(self, inputs, output_size):
+                        width=inputs.shape[-1]
+                        weight=self._params.get_weights(...)
+                                            ^~~~~~~~~~~不支持
+                        return weight
+                def construct(self, x, output_size):
+                    weight = self._fc(x, output_size)
+                    ...""",
+        "Modification Suggestion": "当前版本不支持使用自定义类的属性与方法，请修改自定义类方法，或尝试使用最新版本。",
+        "Fault Case": "1.静态图语法支持： "
+                      "https://www.mindspore.cn/docs/note/zh-CN/r1.6/static_graph_syntax_support.html"},
+    {
+     "ID": "compiler_id_17",
+     "Fault Name": "静态图代码缩进错误",
      "Key Log Information": "incorrect indentations in definition or comment",
      "Key Python Stack Information": "",
      "Key C++ Stack Information": "",
@@ -382,10 +477,11 @@ compiler_experience_list_cn = [
                         # x + 2.0
                         ^~~~~~~~~~~~~~修改注释行对齐
                         return x + self.y""",
-     "Fault Case": """静态图语法： 
-                   https://www.mindspore.cn/docs/note/zh-CN/r1.6/static_graph_syntax_support.html""" },
+     "Fault Case": """1.静态图语法： 
+                   https://www.mindspore.cn/docs/note/zh-CN/r1.6/static_graph_syntax_support.html"""},
     {
-     "Fault Type": "Parameter重名报错",
+     "ID": "compiler_id_18",
+     "Fault Name": "Parameter重名报错",
      "Key Log Information":"value.* Parameter (.*) , its name .* already exists.",
      "Key Python Stack Information": "",
      "Key C++ Stack Information": "",
@@ -397,12 +493,28 @@ compiler_experience_list_cn = [
       "Fault Case":"1. mindspore.Parameter接口: "
                    "https://www.mindspore.cn/docs/zh-CN/r1.8/api_python/mindspore/mindspore.Parameter.html "
                    "2. mindspore.PrameterTuple接口： "
-                   "https://www.mindspore.cn/docs/zh-CN/r1.8/api_python/mindspore/mindspore.ParameterTuple.html " }
+                   "https://www.mindspore.cn/docs/zh-CN/r1.8/api_python/mindspore/mindspore.ParameterTuple.html "},
+    {
+        "ID": "compiler_id_19",
+        "Fault Name": "静态图模式下使用了错误的框架API",
+        "Key Log Information": "Unsupported statement \'Try\'",
+        "Key Python Stack Information": "",
+        "Key C++ Stack Information": "ParseStatement",
+        "Fault Cause": "静态图模式下网络的construct函数、@ms_function修饰的函数或@ms.jit修饰的函数中出现如下问题： "
+                       "1）直接或者间接使用了try语法，此语法静态图模式不支持; "
+                       "2）直接或间接的调用了MindSpore的get_context接口（get_context接口会使用try语法），此接口不能在construct "
+                       "等函数中调用; ",
+        "Modification Suggestion": "1）找到函数中直接或者间接使用了try语法, 将try语法在函数中移除; "
+                                   "2）函数中调用的get_context()接口，迁移到函数外调用; "
+                                   "3）如果没发现调用函数位置，则可能为函数多级调用或者框架内部多级调用，可去社区提单求助",
+        "Fault Case": "1.静态图语法支持： "
+                      "https://www.mindspore.cn/docs/note/zh-CN/r1.6/static_graph_syntax_support.html "}
 ]
 
 compiler_general_experience_list_cn = [
     {
-     "Fault Type": "静态图类型推导问题",
+     "ID": "compiler_g_id_1",
+     "Fault Name": "静态图类型推导问题",
      "Key Log Information": "Get instructions about .analyze_fail.dat.",
      "Key Python Stack Information": "",
      "Key C++ Stack Information": "",
@@ -422,14 +534,15 @@ compiler_general_experience_list_cn = [
                    "5.社区论坛-功能调试案例集： "
                    "https://bbs.huaweicloud.com/forum/forum-1076-2704-1.html "},
     {
-        "Fault Name": "静态图编译问题",
-        "Key Log Information": "",
-        "Key Python Stack Information": "",
-        "Key C++ Stack Information": "mindspore.*\.cc",
-        "Code Path": "mindspore.core.abstract;mindspore.ccsrc.pipeline.jit",
-        "Fault Cause": "可能为静态图的语法编译错误，包括数据类型、原型操作、运算符、复合语句、函数等使用的问题。",
-        "Modification Suggestion": "1.根据报错信息，分析编译报错的类型； "
-                                   "2.针对报错的类型，查看官网静态图语法支持介绍，分析报错的原因; ",
-        "Fault Case": "1.图编译语法支持： "
-                      " https://www.mindspore.cn/docs/note/zh-CN/r1.6/static_graph_syntax_support.html "}
+     "ID": "compiler_g_id_2",
+     "Fault Name": "静态图编译问题",
+     "Key Log Information": "",
+     "Key Python Stack Information": "",
+     "Key C++ Stack Information": "mindspore.*\.cc",
+     "Code Path": "mindspore.core.abstract;mindspore.ccsrc.pipeline.jit",
+     "Fault Cause": "可能为静态图的语法编译错误，包括数据类型、原型操作、运算符、复合语句、函数等使用的问题。",
+     "Modification Suggestion": "1.根据报错信息，分析编译报错的类型； "
+                                "2.针对报错的类型，查看官网静态图语法支持介绍，分析报错的原因; ",
+     "Fault Case": "1.图编译语法支持： "
+                   " https://www.mindspore.cn/docs/note/zh-CN/r1.6/static_graph_syntax_support.html "}
 ]
