@@ -1,4 +1,4 @@
-# Copyright 2022 Tiger Miao
+# Copyright 2022 Tiger Miao and collaborators.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,7 +14,9 @@
 # ============================================================================
 
 operators_experience_list_cn = [
-    {"Fault Type": "Conv2D算子参数错误",
+    {
+     "ID": "operator_id_1",
+     "Fault Name": "Conv2D算子参数错误",
      "Key Log Information": "For primitive.*, the x shape size must be equal to .*, but got .*",
      "Key Python Stack Information": "",
      "Key C++ Stack Information": "",
@@ -34,8 +36,10 @@ operators_experience_list_cn = [
                    "https://www.mindspore.cn/docs/api/zh-CN/r1.6/api_python/nn/mindspore.nn.Conv2d.html "
                    "2. Conv2d算子报错案例： "
                    "https://bbs.huaweicloud.com/forum/thread-182006-1-1.html"},
-    {"Fault Type": "Pad算子参数错误",
-     "Key Log Information": "all elements of \'paddings\' must be >= 0",
+    {
+     "ID": "operator_id_2",
+     "Fault Name": "Pad算子参数错误",
+     "Key Log Information": "all elements of .*paddings.* must be >= 0.*",
      "Key Python Stack Information": "",
      "Key C++ Stack Information": "",
      "Fault Cause": "Pad算子参数paddings不支持负数",
@@ -62,7 +66,9 @@ operators_experience_list_cn = [
                    "https://www.mindspore.cn/docs/api/zh-CN/r1.6/api_python/nn/mindspore.nn.Pad.html "
                    "2. nn.Pad 报错案例： "
                    "https://bbs.huaweicloud.com/forum/thread-182187-1-1.html"},
-    {"Fault Type": "Pad算子参数错误",
+    {
+     "ID": "operator_id_3",
+     "Fault Name": "Pad算子参数错误-1.8",
      "Key Log Information": "the .paddings.shape. must be int and must =",
      "Key Python Stack Information": "",
      "Key C++ Stack Information": "",
@@ -90,8 +96,41 @@ operators_experience_list_cn = [
                     print(y.shape)""",
      "Fault Case": "1. nn.Pad API: "
                    "https://www.mindspore.cn/docs/api/zh-CN/r1.6/api_python/nn/mindspore.nn.Pad.html "},
+    # Different versions have different error descriptions, and the ID is used repeatedly operator_id_3
+    {
+     "ID": "operator_id_3",
+     "Fault Name": "Pad算子参数错误 > 1.8",
+     "Key Log Information": "paddings.shape.* must equal to input",
+     "Key Python Stack Information": "",
+     "Key C++ Stack Information": "",
+     "Fault Cause": "Pad算子的参数paddings的维度与输入x的维度不一致。",
+     "Error Case": """
+                paddings=((1, 1), (2, 2))
+                pad = nn.Pad(paddings, mode="SYMMETRIC")
+                data = np.array([[[[1, 2, 3], [4, 5, 6]]]])
+                print(data.shape)
+                x = Tensor(data, mindspore.float32)
+                print("x=",x.shape)
+                y = pad(x)
+                        ^~~~~~~~~~~~~paddings的维度与输入x的维度不匹配
+                print(y.shape)""",
+     "Modification Suggestion": "修改Pad算子的参数paddings或者输入参数x，保证shape与输入参数x一致。",
+     "Fixed Case": """
+                paddings=((0,0),(0,0),(1,1),(2,2))
+                           ^~~~~~^~~~~~表示前两个维度不进行pad
+                pad = nn.Pad(paddings, mode="SYMMETRIC")
+                data = np.array([[[[1, 2, 3], [4, 5, 6]]]])
+                x = Tensor(data, mindspore.float32)
+                x = x.squeeze()
+                print("x=",x.shape)
+                y = pad(x)
+                print(y.shape)""",
+     "Fault Case": "1. nn.Pad API: "
+                   "https://www.mindspore.cn/docs/api/zh-CN/r1.6/api_python/nn/mindspore.nn.Pad.html "},
     # only 'paddings' up to 4 dims is supported
-    {"Fault Type": "Pad算子参数错误",
+    {
+     "ID": "operator_id_5",
+     "Fault Name": "Pad算子参数错误",
      "Key Log Information": "only 'paddings' up to 4 dims is supported",
      "Key Python Stack Information": "",
      "Key C++ Stack Information": "",
@@ -118,7 +157,9 @@ operators_experience_list_cn = [
                     print(y.shape)""",
      "Fault Case": "1. nn.Pad API: "
                    "https://www.mindspore.cn/docs/api/zh-CN/r1.6/api_python/nn/mindspore.nn.Pad.html "},
-    {"Fault Type": "ReduceSum 算子编译报错",
+    {
+     "ID": "operator_id_6",
+     "Fault Name": "ReduceSum 算子编译报错",
      "Key Log Information": "the num of dimensions of input.* should be .* range of .0, 8., but .*",
      "Key Python Stack Information": "",
      "Key C++ Stack Information": "",
@@ -140,7 +181,9 @@ operators_experience_list_cn = [
                    "https://www.mindspore.cn/docs/zh-CN/master/api_python/ops/mindspore.ops.ReduceSum.html "
                    "2. ReduceSum算子参数错误案例： "
                    "https://bbs.huaweicloud.com/forum/thread-182168-1-1.html"},
-    {"Fault Type": "损失函数的输入参数不匹配报错",
+    {
+     "ID": "operator_id_7",
+     "Fault Name": "损失函数的输入参数不匹配报错",
      "Key Log Information": "For primitive\[.*Entropy.*\], the x shape.* must be equal to.*",
      "Key Python Stack Information": "",
      "Key C++ Stack Information": "",
@@ -150,7 +193,9 @@ operators_experience_list_cn = [
                    "https://www.mindspore.cn/docs/api/zh-CN/r1.6/api_python/mindspore.ops.html "
                    "2. 损失函数报错案例:  "
                    "https://bbs.huaweicloud.com/forum/forum.php?mod=viewthread&tid=182186"},
-    {"Fault Type": "损失函数的输入参数不匹配报错",
+    {
+     "ID": "operator_id_8",
+     "Fault Name": "损失函数的输入参数不匹配报错",
      "Key Log Information": "For '.*Loss', the 'logits_shape' should be .*",
      "Key Python Stack Information": "",
      "Key C++ Stack Information": "",
@@ -160,7 +205,9 @@ operators_experience_list_cn = [
                    "https://www.mindspore.cn/docs/en/r1.7/acatpi_python/mindspore.nn.html#loss-function "
                    "2. 损失函数报错案例:  "
                    "https://bbs.huaweicloud.com/forum/forum.php?mod=viewthread&tid=182186"},
-    {"Fault Type": "算子输入参数不匹配报错",
+    {
+     "ID": "operator_id_9",
+     "Fault Name": "算子输入参数不匹配报错",
      "Key Log Information": "x.shape and y.shape need to broadcast",
      "Key Python Stack Information": "",
      "Key C++ Stack Information": "",
@@ -182,7 +229,9 @@ operators_experience_list_cn = [
                    "https://www.mindspore.cn/docs/zh-CN/master/api_python/ops/mindspore.ops.Sub.html "
                    "2. Sub算子broadcast报错: "
                    "https://bbs.huaweicloud.com/forum/forum.php?mod=viewthread&tid=182004"},
-    {"Fault Type": "view/Reshape算子参数不匹配报错",
+    {
+     "ID": "operator_id_10",
+     "Fault Name": "view/Reshape算子参数不匹配报错",
      "Key Log Information": "product of the shape of 'input_x' should be equal to",
      "Key Python Stack Information": "",
      "Key C++ Stack Information": "",
@@ -204,8 +253,10 @@ operators_experience_list_cn = [
                    "https://www.mindspore.cn/docs/zh-CN/master/api_python/mindspore/mindspore.Tensor.html#mindspore.Tensor.view  "
                    "2. Tensor.view 使用错误案例： "
                    "https://bbs.huaweicloud.com/forum/forum.php?mod=viewthread&tid=181982"},
-    {"Fault Type": "view/Reshape算子参数不匹配报错",
-     "Key Log Information": "product of the 'input_x' shape should be equal to",
+    {
+     "ID": "operator_id_11",
+     "Fault Name": "view/Reshape算子参数不匹配报错-1.9",
+     "Key Log Information": "For .*Reshape.* the product of the 'input_x' shape should be equal to",
      "Key Python Stack Information": "",
      "Key C++ Stack Information": "",
      "Fault Cause": "调用Reshape算子，或者使用其他接口（如view）间接调用Reshape算子。如果reshape后Tensor元素总数量与原Tensor的不匹配，则报错。",
@@ -226,7 +277,33 @@ operators_experience_list_cn = [
                    "https://www.mindspore.cn/docs/zh-CN/master/api_python/mindspore/mindspore.Tensor.html#mindspore.Tensor.view  "
                    "2. Tensor.view 使用错误案例： "
                    "https://bbs.huaweicloud.com/forum/forum.php?mod=viewthread&tid=181982"},
-    {"Fault Type": "算子不支持参数类型报错",
+    {
+     "ID": "operator_id_12",
+     "Fault Name": "view/Reshape算子参数不匹配报错-2.0",
+     "Key Log Information": "For .*Reshape.* the product of the 'input_x' shape should be equal to",
+     "Key Python Stack Information": "",
+     "Key C++ Stack Information": "",
+     "Fault Cause": "调用Reshape算子，或者使用其他接口（如view）间接调用Reshape算子。如果reshape后Tensor元素总数量与原Tensor的不匹配，则报错。",
+     "Error Case": """
+                data = np.random.randint(100, size=(20, 4))
+                x = mindspore.Tensor(data,mindspore.float32)
+                x = x.view((-1,3))
+                #              ^~~~~~~~输入参数x的元素数量并不能被3整除
+                print(x.shape)""",
+     "Modification Suggestion": "检查Tensor.view或者ops.Reshape算子的输入参数shape与原Tensor的shape的差异，找出元素总量不匹配的原因，修正至符合要求。",
+     "Fixed Case": """
+                data = np.random.randint(100, size=(20, 4))
+                x = mindspore.Tensor(data,mindspore.float32)
+                x = x.view((-1,8))
+                #              ^~~~~~~~输入参数x的元素数量能被8整除
+                print(x.shape)""",
+     "Fault Case": "1. Tensor.view API： "
+                   "https://www.mindspore.cn/docs/zh-CN/master/api_python/mindspore/Tensor/mindspore.Tensor.view.html  "
+                   "2. Tensor.view 使用错误案例： "
+                   "https://bbs.huaweicloud.com/forum/forum.php?mod=viewthread&tid=181982"},
+    {
+     "ID": "operator_id_13",
+     "Fault Name": "算子不支持参数类型报错",
      "Key Log Information": "Unsupported parameter type for python primitive, the parameter value is KeywordArg",
      "Key Python Stack Information": "",
      "Key C++ Stack Information": "ConvertAbstractToPython",
@@ -244,11 +321,13 @@ operators_experience_list_cn = [
                     x = Tensor(data, mindspore.float32)
                     out = reduce_mean(x, (2, 3)) 
                     #                    ^~~~~~~~~~输入参数支持tuple类型""",
-     "Fault Case": "1. ReduceMean算子输入键值对参数报错： "
+     "Fault Case": "1.ReduceMean算子输入键值对参数报错： "
                    "https://bbs.huaweicloud.com/forum/forum.php?mod=viewthread&tid=182167 "
-                   "2. ReduceMean API: "
+                   "2.ReduceMean API: "
                    "https://www.mindspore.cn/docs/api/zh-CN/r1.6/api_python/ops/mindspore.ops.ReduceMean.html"},
-    {"Fault Type": "SoftmaxCrossEntropyWithLogits接口使用报错",
+    {
+     "ID": "operator_id_14",
+     "Fault Name": "SoftmaxCrossEntropyWithLogits接口使用报错",
      "Key Log Information": "For primitive\[SoftmaxCrossEntropyWithLogits\], the dimension of logits must be equal to ., but got .",
      "Key Python Stack Information": "",
      "Key C++ Stack Information": "",
@@ -274,7 +353,9 @@ operators_experience_list_cn = [
                     #             ^~~~~~~~^~~~~~~~输入入参数维度，符合（N,C）格式""",
      "Fault Case": "1. SoftmaxCrossEntropyWithLogits API: "
                    "https://www.mindspore.cn/docs/api/zh-CN/r1.6/api_python/nn/mindspore.nn.SoftmaxCrossEntropyWithLogits.html"},
-    {"Fault Type": "算子选择类型不支持报错",
+    {
+     "ID": "operator_id_15",
+     "Fault Name": "算子选择类型不支持报错",
      "Key Log Information": "Can not select a valid kernel info for .* in .*",
      "Key Python Stack Information": "",
      "Key C++ Stack Information": "",
@@ -296,11 +377,13 @@ operators_experience_list_cn = [
                     out = _pow(input_x, input_y)
                     #            ^~~~~~~~~~~~~ops.Pow支持float32类型
                     print(out)""",
-     "Fault Case": "1. ops.Pow API: "
+     "Fault Case": "1.ops.Pow API: "
                    "https://www.mindspore.cn/docs/api/zh-CN/r1.6/api_python/ops/mindspore.ops.Pow.html"
-                   "2. ops.Pow算子报错案例: "
+                   "2.ops.Pow算子报错案例: "
                    "https://bbs.huaweicloud.com/forum/forum.php?mod=viewthread&tid=182027"},
-    {"Fault Type": "算子参数不支持报错",
+    {
+     "ID": "operator_id_16",
+     "Fault Name": "算子参数不支持报错",
      "Key Log Information": "Unsupported input type for .*",
      "Key Python Stack Information": "",
      "Key C++ Stack Information": "",
@@ -318,11 +401,13 @@ operators_experience_list_cn = [
                     output = ops.scalar_add(x, y)
                     #                       ^~~~~~~不支持输入参数类型BOOL
                     print('output', output)""",
-     "Fault Case": "1. ops.scalar_add API: "
+     "Fault Case": "1.ops.scalar_add API: "
                    "https://www.mindspore.cn/docs/api/zh-CN/r1.6/api_python/mindspore.ops.html?highlight=scalar_add "
-                   "2. ops.scalar_add()算子报错案例: "
+                   "2.ops.scalar_add()算子报错案例: "
                    "https://bbs.huaweicloud.com/forum/forum.php?mod=viewthread&tid=182173"},
-    {"Fault Type": "算子参数不支持报错-r1.6",
+    {
+     "ID": "operator_id_17",
+     "Fault Name": "算子参数不支持报错-r1.6",
      "Key Log Information": "input var is a not support implicit conversion",
      "Key Python Stack Information": "",
      "Key C++ Stack Information": "",
@@ -343,7 +428,9 @@ operators_experience_list_cn = [
                     print(output)""",
      "Fault Case": "1. ops.Mul API: "
                    "https://www.mindspore.cn/docs/api/zh-CN/r1.6/api_python/ops/mindspore.ops.Mul.html "},
-    {"Fault Type": "算子参数不支持报错-r1.8",
+    {
+     "ID": "operator_id_18",
+     "Fault Name": "算子参数不支持报错-r1.8",
      "Key Log Information": "input var can not be implicitly converted",
      "Key Python Stack Information": "",
      "Key C++ Stack Information": "",
@@ -364,7 +451,9 @@ operators_experience_list_cn = [
                     print(output)""",
      "Fault Case": "1. ops.Mul API: "
                    "https://www.mindspore.cn/docs/zh-CN/r1.7/api_python/ops/mindspore.ops.Mul.html "},
-    {"Fault Type": "算子反向未定义错误",
+    {
+     "ID": "operator_id_19",
+     "Fault Name": "算子反向未定义错误",
      "Key Log Information": "Illegal primitive: Primitive .* bprop not defined",
      "Key Python Stack Information": "",
      "Key C++ Stack Information": "",
@@ -377,7 +466,8 @@ operators_experience_list_cn = [
 ]
 operators_general_experience_list_cn = [
  {
-  "Fault Type": "算子选择错误",
+  "ID": "operator_g_id_1",
+  "Fault Name": "算子选择错误",
   "Key Log Information": "Can not find any available kernel info;Can not select a valid kernel info",
   "Key Python Stack Information": "",
   "Key C++ Stack Information": "",
@@ -391,7 +481,8 @@ operators_general_experience_list_cn = [
                 "https://www.mindspore.cn/docs/zh-CN/r1.8/faq/operators_compile.html "
  },
  {
-  "Fault Type": "算子使用错误",
+  "ID": "operator_g_id_2",
+  "Fault Name": "算子使用错误",
   "Key Log Information": "For primitive\[.*\], the .* must be .*;For primitive\[.*\], the .* should be .*;"
                          "For '.*', the .* must be;For '.*', the .* should be",
   "Key Python Stack Information": "mindspore.python.mindspore.ops",
